"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const zos_jobs_for_zowe_sdk_1 = require("@zowe/zos-jobs-for-zowe-sdk");
const zosmf_for_zowe_sdk_1 = require("@zowe/zosmf-for-zowe-sdk");
/**
 * "zos-jobs search job" command handler. Modify a job by name and ID.
 * @export
 * @class JobHandler
 * @implements {ICommandHandler}
 */
class JobHandler extends zosmf_for_zowe_sdk_1.ZosmfBaseHandler {
    /**
     * Command handler process - invoked by the command processor to handle the "zos-jobs search job"
     * @param {IHandlerParameters} params - Command handler parameters
     * @returns {Promise<void>} - Fulfilled when the command completes successfully OR rejected with imperative error
     * @memberof JobHandler
     */
    processCmd(params) {
        return __awaiter(this, void 0, void 0, function* () {
            this.arguments = params.arguments;
            const searchParms = { jobName: this.arguments.jobname,
                caseInsensitive: this.arguments.caseInsensitive,
                searchLimit: this.arguments.searchLimit,
                fileLimit: this.arguments.fileLimit };
            if (this.arguments.searchString != undefined)
                searchParms.searchString = encodeURI(this.arguments.searchString);
            if (this.arguments.searchRegex != undefined)
                searchParms.searchRegex = encodeURI(this.arguments.searchRegex);
            // Get the job details
            const dsContentBuf = yield zos_jobs_for_zowe_sdk_1.SearchJobs.searchJobs(this.mSession, searchParms);
            // If no string was found then set the exit code
            if (dsContentBuf.length == 0) {
                this.data.setExitCode(1);
            }
            else {
                this.data.setExitCode(0);
            }
            this.data.setObj(dsContentBuf);
            this.console.log(Buffer.from(dsContentBuf));
        });
    }
}
exports.default = JobHandler;
//# sourceMappingURL=Job.handler.js.map